@@ -19,7 +19,7 @@ from jsonschema import Draft4Validator
 from jsonschema.validators import extend as extend_validator
 
 from .exceptions import InvalidSpecification
-from .json_schema import NullableTypeValidator, resolve_refs
+from .json_schema import NullableTypeValidator, URLHandler, resolve_refs
 from .operations import AbstractOperation, OpenAPIOperation, Swagger2Operation
 from .utils import deep_get
 
@@ -158,6 +158,14 @@ class Specification(Mapping):
         spec = cls._load_spec_from_file(arguments, specification_path)
         return cls.from_dict(spec, base_uri=base_uri)
 
+    @classmethod
+    def from_url(cls, spec, *, base_uri=""):
+        """
+        Takes in a path to a YAML file, and returns a Specification
+        """
+        spec = URLHandler()(spec)
+        return cls.from_dict(spec, base_uri=base_uri)
+
     @staticmethod
     def _get_spec_version(spec):
         try:
@@ -200,6 +208,10 @@ class Specification(Mapping):
 
     @classmethod
     def load(cls, spec, *, arguments=None):
+        if isinstance(spec, str) and (
+            spec.startswith("http://") or spec.startswith("https://")
+        ):
+            return cls.from_url(spec)
         if not isinstance(spec, dict):
             base_uri = f"{pathlib.Path(spec).parent}{os.sep}"
             return cls.from_file(spec, arguments=arguments, base_uri=base_uri)
